summaryrefslogtreecommitdiffstats
path: root/ark/filelistview.cpp
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 10:00:17 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 10:00:17 -0600
commit955e20356d63ed405198c8143617a8a0ca8bfc02 (patch)
tree9a9ab22c86d212a5655014ad752e96b04c0c86a9 /ark/filelistview.cpp
parentbf280726d5d22f33d33e4f9e771220c725249407 (diff)
downloadtdeutils-955e20356d63ed405198c8143617a8a0ca8bfc02.tar.gz
tdeutils-955e20356d63ed405198c8143617a8a0ca8bfc02.zip
Revert "Rename a number of old tq methods that are no longer tq specific"
This reverts commit bf280726d5d22f33d33e4f9e771220c725249407.
Diffstat (limited to 'ark/filelistview.cpp')
-rw-r--r--ark/filelistview.cpp22
1 files changed, 11 insertions, 11 deletions
diff --git a/ark/filelistview.cpp b/ark/filelistview.cpp
index ca941bd..5aa1122 100644
--- a/ark/filelistview.cpp
+++ b/ark/filelistview.cpp
@@ -153,7 +153,7 @@ void FileLVI::setText( int column, const TQString &text )
else
m_ratio = text.toDouble();
TQListViewItem::setText( column, i18n( "Packed Ratio", "%1 %" )
- .arg(KGlobal::locale()->formatNumber( m_ratio, 1 ) )
+ .tqarg(KGlobal::locale()->formatNumber( m_ratio, 1 ) )
);
}
else if ( colName == timeStampStrCol )
@@ -264,14 +264,14 @@ TQStringList FileListView::selectedFilenames()
{
if ( item->isSelected() )
{
// If the item has children, add each child and the item
if ( item->childCount() > 0 )
{
files += item->fileName();
- files += childrenOf( item );
+ files += tqchildrenOf( item );
/* If we got here, then the logic for "going to the next item"
* is a bit different: as we already dealt with all the children,
* the "next item" is the next sibling of the current item, not
* its first child. If the current item has no siblings, then
* the next item is the next sibling of its parent, and so on.
@@ -288,7 +288,7 @@ TQStringList FileListView::selectedFilenames()
}
else
{
// If the item has no children, just add it to the list
files += item->fileName();
}
}
@@ -559,10 +559,10 @@ FileLVI* FileListView::findParent( const TQString& fullname )
return static_cast< FileLVI* >( item );
}
-TQStringList FileListView::childrenOf( FileLVI* parent )
+TQStringList FileListView::tqchildrenOf( FileLVI* parent )
{
Q_ASSERT( parent );
- TQStringList children;
+ TQStringList tqchildren;
FileLVI *item = static_cast<FileLVI*>( parent->firstChild() );
@@ -570,17 +570,17 @@ TQStringList FileListView::childrenOf( FileLVI* parent )
{
if ( item->childCount() == 0 )
{
- children += item->fileName();
+ tqchildren += item->fileName();
}
else
{
- children += item->fileName();
- children += childrenOf( item );
+ tqchildren += item->fileName();
+ tqchildren += tqchildrenOf( item );
}
item = static_cast<FileLVI*>( item->nextSibling() );
}
- return children;
+ return tqchildren;
}
#include "filelistview.moc"
@@ -264,14 +264,14 @@ TQStringList FileListView::selectedFilenames()
if ( item->isSelected() )
{
- // If the item has children, add each child and the item
+ // If the item has tqchildren, add each child and the item
if ( item->childCount() > 0 )
{
@@ -264,14 +264,14 @@ TQStringList FileListView::selectedFilenames()
/* If we got here, then the logic for "going to the next item"
- * is a bit different: as we already dealt with all the children,
+ * is a bit different: as we already dealt with all the tqchildren,
* the "next item" is the next sibling of the current item, not
* its first child. If the current item has no siblings, then
@@ -288,7 +288,7 @@ TQStringList FileListView::selectedFilenames()
else
{
- // If the item has no children, just add it to the list
+ // If the item has no tqchildren, just add it to the list
files += item->fileName();
}